# ansible.builtin.debug
This module prints statements during execution and can be useful for debugging variables or expressions without necessarily halting the playbook.

## Parameter
| Parameter     | Type    | Default        | Description                                                                                              |
| ------------- | ------- | -------------- | -------------------------------------------------------------------------------------------------------- |
| **msg**       | string  | "Hello world!" | The customized message that is printed. If omitted, prints a generic message.                            |
| **var**       | string  | -              | A variable name to debug.  Mutually exclusive with the msg option.                                       |
| **verbosity** | integer | 0              | A number that controls when the debug is run, if you set to 3 it will only run debug when -vvv or above. |

## Examples
```yaml
- name: Print the gateway for each host when defined
  ansible.builtin.debug:
    msg: System {{ inventory_hostname }} has gateway {{ ansible_default_ipv4.gateway }}
  when: ansible_default_ipv4.gateway is defined

- name: Get uptime information
  ansible.builtin.shell: /usr/bin/uptime
  register: result

- name: Print return information from the previous task
  ansible.builtin.debug:
    var: result
    verbosity: 2

- name: Display all variables/facts known for a host
  ansible.builtin.debug:
    var: hostvars[inventory_hostname]
    verbosity: 4

- name: Prints two lines of messages, but only if there is an environment value set
  ansible.builtin.debug:
    msg:
    - "Provisioning based on YOUR_KEY which is: {{ lookup('ansible.builtin.env', 'YOUR_KEY') }}"
    - "These servers were built using the password of '{{ password_used }}'. Please retain this for later use."
```